.. bulk-mv documentation master file, created by
   sphinx-quickstart on Sun Apr  2 21:26:33 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to usau-scraper's documentation!
===========================================


.. toctree::
   :maxdepth: 2
   :caption: Contents:

Installation
===================================
:code:`pip install usau-scraper`

How to Use
===================================
After installing the library, there are currently 3 functions available for use: getTeamInfo, getTeamSchedule, and getTeamRoster.

Simply :code:`import * from usau_scraper`, and then call any of the following functions:

.. automodule:: usau_scraper.teamScraper
   :members:
   :show-inheritance:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
